@@ -30,7 +30,8 @@ def authenticate():
 
 
 @argh.arg('-v', '--value', nargs='+', type=str)
-def lookup(project: "ATLAS Subproject" = 'S',
+def lookup(project: "ATLAS Project" = 'S',
+           subProject: "ATLAS Subproject" = "SE",
            lookupKey: "Key that corresponds to VALUE" = 'serialNumber',
            value: "Values to look up (can be a list)" = None,
            componentType: "Type of component" = 'BT',
@@ -45,7 +46,7 @@ def lookup(project: "ATLAS Subproject" = 'S',
             value = [value]
         client = itkdb.Client()
         components = client.get('listComponents', json={
-                                'project': project, "componentType": componentType})
+                                'project': project, "componentType": componentType, "subproject": subProject})
         results = {}
         logger.info(f"Looking up {lookupKey} = {value}")
         for i, comp in enumerate(components):
@@ -151,13 +152,14 @@ def tests(componentType: "Type of component" = "BT",
 
 def stage(lookupValue: "Value to look up (must be unique in the DB!)",
           stage: "Production stage to set",
-          project: "ATLAS Subproject" = 'S',
+          project: "ATLAS Project" = 'S',
+          subProject: "ATLAS Subproject" = "SE",
           lookupKey: "Key that corresponds to VALUE" = 'serialNumber',
           componentType: "Type of component" = 'BT',
           comment: "Reason for production stage change" = ""):
     "Set or look up production stage for a component."
     logger.info(f"Getting component from the DB")
-    component = lookup(project=project, lookupKey=lookupKey, value=[
+    component = lookup(project=project, subProject=subProject, lookupKey=lookupKey, value=[
                        lookupValue], componentType=componentType, returnResults=True)
     if len(component) == 0:
         logger.error(
@@ -192,7 +194,7 @@ def stage(lookupValue: "Value to look up (must be unique in the DB!)",
 
 def skeleton(test: "Type of test",
              componentType: "Type of component" = "BT",
-             project: "ATLAS Subproject" = 'S',
+             project: "ATLAS Project" = 'S',
              returnResults: "Return available tests (useful if not used from CLI)" = False):
     "Genereate a test skeleton for a given test. Otput is either as JSON to the CLI or as a dict as a return value."
     allTests = tests(componentType=componentType,
@@ -274,7 +276,7 @@ def testfile(file: "Path of the file to upload",
              testrun: "Test run code",
              title: "Title of the file" = "",
              description: "A file description" = "",
-             filetype: "File MIME type (sript can usually guess this)" = None):
+             filetype: "File MIME type (script can usually guess this)" = None):
     "Attach a file to a testrun in the DB."
     try:
         client = itkdb.Client()
